@@ -9,14 +9,14 @@ zoo <- function (x = NULL, order.by = index(x), frequency = NULL)
 
     if(missing(x) || is.null(x)) 
       x <- numeric()
-    else if (is.vector(x)) 
-      x <- rep(x, length.out = length(index))[index]
-    else if (is.factor(x))         
+    else if(is.factor(x))         
       x <- factor(rep(as.character(x), length.out = length(index))[index],
         levels = levels(x), ordered = is.ordered(x))
-    else if (is.matrix(x) || is.data.frame(x)) 
+    else if(is.matrix(x) || is.data.frame(x)) 
       x <- (x[rep(1:NROW(x), length.out = length(index)), , 
         drop = FALSE])[index, , drop = FALSE]
+    else if(is.atomic(x)) 
+      x <- rep(x, length.out = length(index))[index]
     else stop(paste(dQuote("x"), ": attempt to define illegal zoo object"))
     if(is.matrix(x) || is.data.frame(x)) x <- as.matrix(x)
 
@@ -33,6 +33,8 @@ zoo <- function (x = NULL, order.by = index(x), frequency = NULL)
         if(frequency > 1 && identical(all.equal(frequency, round(frequency)), TRUE))
 	  frequency <- round(frequency)
       }
+      if(!is.null(frequency) && identical(class(order.by), "numeric") | identical(class(order.by), "integer"))
+        order.by <- floor(frequency * order.by + .0001)/frequency
     }
 
     attr(x, "oclass") <- attr(x, "class")
@@ -53,7 +55,9 @@ print.zoo <- function (x, style = ifelse(length(dim(x)) == 0,
         if (length(colnames(x)) < 1) {
             colnames(y) <- rep("", NCOL(x))
         }
-        rownames(y) <- index2char(index(x), frequency = attr(x, "frequency"))
+		if (NROW(y) > 0) {
+			rownames(y) <- index2char(index(x), frequency = attr(x, "frequency"))
+		}
         print(y, quote = quote, ...)
     }
     else if (style == "horizontal") {
@@ -242,6 +246,7 @@ rev.zoo <- function(x) {
 }
 
 ifelse.zoo <- function(test, yes, no) {
+	if(!is.zoo(test)) test <- zoo(test, index(yes))
 	merge(test, yes, no, retclass = NULL)
 	ifelse(test, yes, no)
 }
